#include "hznpredictor.h"

// denominator, numerator1, ..., numerator7
const int
HZNpredictor::weight[][8] = {
  { 1,  0,  0,  0,  0,  0,  0,  0 }, // 00
  { 1,  1,  0,  0,  0,  0,  0,  0 }, // 01
  { 1,  0,  1,  0,  0,  0,  0,  0 }, // 02
  { 2,  1,  1,  0,  0,  0,  0,  0 }, // 03
  { 1,  0,  0,  1,  0,  0,  0,  0 }, // 04
  { 1,  1,  0,  0,  0,  0,  0,  0 }, // 05
  { 1,  0,  1,  0,  0,  0,  0,  0 }, // 06
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 07
  { 1,  0,  0,  0,  1,  0,  0,  0 }, // 08
  { 2,  1,  0,  0,  1,  0,  0,  0 }, // 09
  { 2,  0,  1,  0,  1,  0,  0,  0 }, // 0a
  { 3,  1,  1,  0,  1,  0,  0,  0 }, // 0b
  { 3,  0,  0,  1,  2,  0,  0,  0 }, // 0c
  { 2,  1,  0,  0,  1,  0,  0,  0 }, // 0d
  { 2,  0,  1,  0,  1,  0,  0,  0 }, // 0e
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 0f
  { 1,  0,  0,  0,  0,  1,  0,  0 }, // 10
  { 1,  1,  0,  0,  0,  0,  0,  0 }, // 11
  { 3,  0,  2,  0,  0,  1,  0,  0 }, // 12
  { 2,  1,  1,  0,  0,  0,  0,  0 }, // 13
  { 2,  0,  0,  1,  0,  1,  0,  0 }, // 14
  { 1,  1,  0,  0,  0,  0,  0,  0 }, // 15
  { 2,  0,  2, -1,  0,  1,  0,  0 }, // 16
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 17
  { 1,  0,  0,  0,  1,  0,  0,  0 }, // 18
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 19
  { 2,  0,  1,  0,  1,  0,  0,  0 }, // 1a
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 1b
  { 2,  0,  0,  1,  2, -1,  0,  0 }, // 1c
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 1d
  { 2,  0,  1,  0,  1,  0,  0,  0 }, // 1e
  { 2,  2,  1, -1,  1, -1,  0,  0 }, // 1f
  { 1,  0,  0,  0,  0,  0,  1,  0 }, // 20
  { 3,  2,  0,  0,  0,  0,  1,  0 }, // 21
  { 1,  0,  1,  0,  0,  0,  0,  0 }, // 22
  { 2,  1,  1,  0,  0,  0,  0,  0 }, // 23
  { 2,  0,  0,  1,  0,  0,  1,  0 }, // 24
  { 2,  2,  0, -1,  0,  0,  1,  0 }, // 25
  { 1,  0,  1,  0,  0,  0,  0,  0 }, // 26
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 27
  { 1,  0,  0,  0,  1,  0,  0,  0 }, // 28
  { 2,  1,  0,  0,  1,  0,  0,  0 }, // 29
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 2a
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 2b
  { 2,  0,  0,  1,  2,  0, -1,  0 }, // 2c
  { 2,  1,  0,  0,  1,  0,  0,  0 }, // 2d
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 2e
  { 2,  1,  2, -1,  1,  0, -1,  0 }, // 2f
  { 2,  0,  0,  0,  0,  1,  1,  0 }, // 30
  { 2,  2,  0,  0,  0, -1,  1,  0 }, // 31
  { 2,  0,  2,  0,  0,  1, -1,  0 }, // 32
  { 2,  1,  1,  0,  0,  0,  0,  0 }, // 33
  { 3,  0,  0,  1,  0,  1,  1,  0 }, // 34
  { 1,  2,  0, -1,  0, -1,  1,  0 }, // 35
  { 1,  0,  2, -1,  0,  1, -1,  0 }, // 36
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 37
  { 1,  0,  0,  0,  1,  0,  0,  0 }, // 38
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 39
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 3a
  { 2,  1,  1,  0,  2, -1, -1,  0 }, // 3b
  { 1,  0,  0,  1,  2, -1, -1,  0 }, // 3c
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 3d
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 3e
  { 3,  2,  2, -1,  2, -1, -1,  0 }, // 3f
  { 1,  0,  0,  0,  0,  0,  0,  1 }, // 40
  { 1,  1,  0,  0,  0,  0,  0,  0 }, // 41
  { 1,  0,  1,  0,  0,  0,  0,  0 }, // 42
  { 3,  2,  2,  0,  0,  0,  0, -1 }, // 43
  { 1,  0,  0,  1,  0,  0,  0,  0 }, // 44
  { 1,  1,  0,  0,  0,  0,  0,  0 }, // 45
  { 1,  0,  1,  0,  0,  0,  0,  0 }, // 46
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 47
  { 1,  0,  0,  0,  1,  0,  0,  0 }, // 48
  { 3,  2,  0,  0,  2,  0,  0, -1 }, // 49
  { 3,  0,  2,  0,  2,  0,  0, -1 }, // 4a
  { 2,  1,  1,  0,  1,  0,  0, -1 }, // 4b
  { 1,  0,  0,  1,  1,  0,  0, -1 }, // 4c
  { 1,  0,  0,  1,  1,  0,  0, -1 }, // 4d
  { 1,  0,  0,  1,  1,  0,  0, -1 }, // 4e
  { 3,  2,  2, -1,  1,  0,  0, -1 }, // 4f
  { 1,  0,  0,  0,  0,  1,  0,  0 }, // 50
  { 1,  1,  0,  0,  0,  0,  0,  0 }, // 51
  { 1,  0,  1,  0,  0,  1,  0, -1 }, // 52
  { 1,  0,  1,  0,  0,  1,  0, -1 }, // 53
  { 1,  0,  0,  1,  0,  1,  0, -1 }, // 54
  { 1,  1,  0,  0,  0,  0,  0,  0 }, // 55
  { 1,  0,  1,  0,  0,  1,  0, -1 }, // 56
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 57
  { 1,  0,  0,  0,  1,  0,  0,  0 }, // 58
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 59
  { 1,  0,  1,  0,  0,  1,  0, -1 }, // 5a
  { 3,  2,  1,  0,  2, -1,  0, -1 }, // 5b
  { 1,  0,  0,  1,  1,  0,  0, -1 }, // 5c
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 5d
  { 2,  0,  1,  1,  1,  1,  0, -2 }, // 5e
  { 2,  2,  1, -1,  1, -1,  0,  0 }, // 5f
  { 1,  0,  0,  0,  0,  0,  1,  0 }, // 60
  { 1,  1,  0,  0,  0,  0,  1, -1 }, // 61
  { 1,  0,  1,  0,  0,  0,  0,  0 }, // 62
  { 1,  1,  0,  0,  0,  0,  1, -1 }, // 63
  { 1,  0,  0,  1,  0,  0,  1, -1 }, // 64
  { 1,  1,  0,  0,  0,  0,  1, -1 }, // 65
  { 1,  0,  1,  0,  0,  0,  0,  0 }, // 66
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 67
  { 1,  0,  0,  0,  1,  0,  0,  0 }, // 68
  { 1,  1,  0,  0,  0,  0,  1, -1 }, // 69
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 6a
  { 3,  1,  2,  0,  2,  0, -1, -1 }, // 6b
  { 1,  0,  0,  1,  1,  0,  0, -1 }, // 6c
  { 2,  1,  0,  1,  1,  0,  1, -2 }, // 6d
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 6e
  { 2,  1,  2, -1,  1,  0, -1,  0 }, // 6f
  { 1,  0,  0,  0,  0,  1,  1, -1 }, // 70
  { 1,  1,  0,  0,  0,  0,  1, -1 }, // 71
  { 1,  0,  1,  0,  0,  1,  0, -1 }, // 72
  { 2,  1,  1,  0,  0,  1,  1, -2 }, // 73
  { 1,  0,  0,  1,  0,  1,  1, -2 }, // 74
  { 1,  1,  0,  0,  0,  0,  1, -1 }, // 75
  { 1,  0,  1,  0,  0,  1,  0, -1 }, // 76
  { 1,  1,  1, -1,  0,  0,  0,  0 }, // 77
  { 1,  0,  0,  0,  1,  0,  0,  0 }, // 78
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 79
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 7a
  { 2,  1,  1,  0,  2, -1, -1,  0 }, // 7b
  { 1,  0,  0,  1,  1,  0,  0, -1 }, // 7c
  { 1,  1,  0,  0,  1, -1,  0,  0 }, // 7d
  { 1,  0,  1,  0,  1,  0, -1,  0 }, // 7e
  { 1,  1,  1, -1,  1, -1, -1,  1 }, // 7f
};
